/****************************************************************************
 *  pptpfunc.h    : $Revision:   1.18  $
 *  Modified      : $Date:   May 13 1996 14:48:40  $
 *  By            : $Author:   tmortsol  $, U.S. Robotics Access Corp.
 *****************************************************************************
 *          Copyright (c) $Date:   May 13 1996 14:48:40  $,                  *
 *            U.S. Robotics Access Corp., Microsoft Corp.                    *
 *                       All Rights Reserved                                 *
 *****************************************************************************
 *                          "PPTP MODULE"                                    *
 * This software may be used to implement the POINT to POINT TUNNELING       *
 * PROTOCOL as defined by the PPTP forum.  The PPTP forum consists of:       *
 * U.S. Robotics, Microsoft, Ascend Communications, 3Com/Primary Access,     *
 * Telematics.                                                               *
 *****************************************************************************
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain this entire header
 *    including the above copyright notice, this list of conditions and
 *    the following disclaimer.
 * 2. The name of U.S. Robotics may not be used to endorse or promote
 *    products derived from this software without specific prior written
 *    permission of U.S. Robotics.
 *
 * THIS SOFTWARE IS PROVIDED BY U.S. ROBOTICS ACESS CORP. ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL U.S. ROBOTICS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/
/*END_HEADER*/

/*
 * pptpfunc.h
 *
 * This header file contains definitions for functions used within the
 * PPTP protocol engine.
 */

#if !defined(__pptpfunc_h)
#define __pptpfunc_h

/*
 * Functions within the common PPTP protocol
 */

PptpReturnCode PptpSetCurrentConfig(
	PptpConfig *pPptpConfig
	);


PptpReturnCode PptpInitializeLocks(
	VOID
	);

PptpReturnCode PptpInit(
	VOID
	);

PptpReturnCode PptpAllocateControlChannelForCall(
	PptpCallLineDescriptor	*callLineDescriptorp,
	PptpAddressList   	*pAddressList
	);

PptpReturnCode PptpControlChannelAcceptedCall(
	PptpCallLineDescriptor	*callLineDescriptorp
	);

PptpReturnCode PptpControlChannelRefusedCall(
	PptpCallLineDescriptor	*callLineDescriptorp
	);

PptpReturnCode PptpControlChannelDisconnectedCall(
	PptpCallLineDescriptor	*callLineDescriptorp
	);

PptpReturnCode PptpLocallyDisconnectedCall(
	PptpCallLineDescriptor	*callLineDescriptorp
	);

PptpReturnCode PptpAssignNewCallLineNumber(
	PptpCallLineNumber	*newcallLineNumberp
	);

PptpReturnCode PptpRelinquishCallLine(
	PptpCallLineDescriptor *callLineDescriptorp
	);

PptpReturnCode PptpCallLineNumberToCallLineDescriptorp(
	PptpCallLineNumber	callLineNumber,
	PptpCallLineDescriptor	**callLineDescriptorpp
	);

PptpReturnCode PptpRemoteCallLineNumberToCallLineDescriptorp(
	PptpCallLineNumber		callLineNumber,
	PptpControlChannelDescriptor	*controlChannelDescriptorp,
	PptpCallLineDescriptor		**callLineDescriptorpp
	);

PptpReturnCode PptpCallDeviceNumberToCallLineDescriptorp(
	PptpCallDeviceNumber	callDeviceNumber,
	PptpCallLineDescriptor	**callLineDescriptorp
	);

PptpReturnCode PptpLookupControlChannelDescriptorByHandle(
	PptpEndpointHandle		endpointHandle,
	PptpControlChannelDescriptor	**controlChannelDescriptorpp
	);

PptpReturnCode PptpLookupControlChannelNumberByAddr(
	PptpSockaddrIn			*remoteAddr,
	PptpProtocolNumber		remoteProtocolNumber,
	PptpControlChannelNumber	*controlChannelNumberp
	);

void PptpBuildControlHeader(
	PptpControlMessageHeader	*headerp,
	PptpControlMessageType		messageType,
	USHORT				messageLength
	);

PptpReturnCode PptpSendControlMessage(
	PptpControlChannelDescriptor	*controlChannelDescriptorp,
	PptpControlPacket		*controlPacketp
	);

PptpReturnCode PptpDataChannelSend(
	PptpCallLineNumber			callLineNumber,
	UCHAR					*data,
	ULONG					dataLength,
	BOOL					*dataPacketDeliveredp,
	VOID					*completionArg
	);

PptpReturnCode PptpDataChannelRecvComplete(
	PptpCallLineNumber			callLineNumber,
	VOID					*completionArg
	);

PptpReturnCode PptpGetDebugStateInfo(
	PptpDebugStateInfo	*debugStateInfop
	);

PptpReturnCode PptpScheduleInternalTimer(
	PptpCallbackFunction		callbackFunction,
	PptpCallbackArgument		callbackArgument,
	PptpMsec			milliSeconds,
	PptpInternalTimer		*timer
	);

PptpReturnCode PptpUnscheduleInternalTimer(
	PptpInternalTimer		*timer
	);

/*
 * Functions within the PPTP server specific module
 */

PptpReturnCode PptpServerControlProtocolInput(
	PptpControlChannelDescriptor	*controlChannelDescriptorp,
	PptpControlPacket		*controlPacket
	);
	
PptpReturnCode PptpServerCallLineLostControlChannel(
	PptpCallLineDescriptor		*callLineDescriptorp
	);

PptpReturnCode PptpServerDataChannelRecv(
	PptpCallLineDescriptor		*callLineDescriptorp,
	UCHAR				*data,
	ULONG				dataLength,
	BOOL				*dataPacketDeliveredp,
	VOID				*completionArg
	);

PptpReturnCode PptpServerDataChannelSendComplete(
	VOID				*completionArg
	);

PptpReturnCode PptpServerDataChannelSendAvailable(
	PptpCallLineDescriptor		*callLineDescriptorp
	);

PptpReturnCode PptpServerFlushSendQueue(
	PptpCallDeviceNumber	callDeviceNumber
	);
/*
 * Functions within the PPTP client specific module
 */

PptpReturnCode PptpClientControlProtocolInput(
	PptpControlChannelDescriptor	*controlChannelDescriptorp,
	PptpControlPacket		*controlPacket
	);
	
PptpReturnCode PptpClientCallLineLostControlChannel(
	PptpCallLineDescriptor		*callLineDescriptorp
	);

PptpReturnCode PptpClientDataChannelRecv(
	PptpCallLineDescriptor		*callLineDescriptorp,
	UCHAR				*data,
	ULONG				dataLength,
	BOOL				*dataPacketDeliveredp,
	VOID				*completionArg
	);

PptpReturnCode PptpClientDataChannelSendComplete(
	VOID				*completionArg
	);

PptpReturnCode PptpClientDataChannelSendAvailable(
	PptpCallLineDescriptor		*callLineDescriptorp
	);

#endif /* !defined(__pptpfunc_h) */
